netapp_ontap.resources.cifs_service API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.cifs_service`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

A CIFS server is necessary to provide SMB clients with access to the Storage Virtual Machine (SVM). Before you begin, the following prerequisites must be in place:

- At least one SVM LIF must exist on the SVM.
- The LIFs must be able to connect to the DNS servers configured on the SVM and to an Active Directory domain controller of the domain to which you want to join the CIFS server.
- The DNS servers must contain the service location records that are needed to locate the Active Directory domain services.
- The cluster time must be synchronized to within five minutes of the Active Directory domain controller.

## Performance monitoring

Performance of the SVM can be monitored by the `metric.*` and `statistics.*` properties. These show the performance of the SVM in terms of IOPS, latency and throughput. The `metric.*` properties denote an average whereas `statistics.*` properties denote a real-time monotonically increasing value aggregated across all nodes.

### Information on the CIFS server

You must keep the following in mind when creating the CIFS server:

- The CIFS server name might or might not be the same as the SVM name.
- The CIFS server name can be up to 15 characters in length.
- The following characters are not allowed: @ # * ( ) = + [ ] | ; : " , < > \ / ?
- You must use the FQDN when specifying the domain.
- The default is to add the CIFS server machine account to the Active Directory "CN=Computer" object.
- You can choose to add the CIFS server to a different organizational unit (OU) by specifying the "organizational_unit" parameter. When specifying the OU, do not specify the domain portion of the distinguished name; only specify the OU or CN portion of the distinguished name. ONTAP appends the value provided for the required "-domain" parameter onto the value provided for the "-ou" parameter to create the Active Directory distinguished name, which is used when joining the Active Directory domain.
- You can optionally choose to add a text comment of up to 256 characters about the CIFS server. If there is a space in the comment text, you must enclose the entire string in quotation marks.
- You can optionally choose to add a comma-delimited list of one or more NetBIOS aliases for the CIFS server.
- The initial administrative status of the CIFS server is "up".
- The large-mtu feature is enabled for the new CIFS server.
- The multichannel feature is disabled for the new CIFS server.
- If LDAP is configured with the use_start_tls and session_security features, the new CIFS server will also have this property set.
- The security.kdc_encryption and security.advertised_kdc_encryptions fields are mutually exclusive. Use the advertised_kdc_encryptions field to specify the encryption types to be advertised to the Key Distribution Center (KDC) server in the Active Directory domain.

## Examples

### Creating a CIFS server

To create a CIFS server, use the following API. Note the return_records=true query parameter used to obtain the newly created entry in the response.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsService()
        resource.ad_domain = {
            "fqdn": "ontapavc.com",
            "organizational_unit": "CN=Computers",
            "password": "<PASSWORD-FOR-USER>",
            "user": "administrator",
        }
        resource.comment = "This CIFS Server Belongs to CS Department"
        resource.default_unix_user = "string"
        resource.enabled = True
        resource.name = "CIFS1"
        resource.netbios = {
            "aliases": ["ALIAS_1", "ALIAS_2", "ALIAS_3"],
            "enabled": False,
            "wins_servers": ["10.224.65.20", "10.224.65.21"],
        }
        resource.options = {
            "admin_to_root_mapping": True,
            "advanced_sparse_file": True,
            "copy_offload": True,
            "fake_open": True,
            "fsctl_trim": True,
            "junction_reparse": True,
            "large_mtu": True,
            "multichannel": True,
            "null_user_windows_name": "string",
            "path_component_cache": True,
            "referral": False,
            "smb_credits": 128,
            "widelink_reparse_versions": ["smb1"],
        }
        resource.security = {
            "encrypt_dc_connection": False,
            "kdc_encryption": False,
            "restrict_anonymous": "no_enumeration",
            "session_security": "none",
            "smb_encryption": False,
            "smb_signing": False,
            "use_ldaps": False,
            "use_start_tls": False,
        }
        resource.svm = {"name": "vs1", "uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"}
        resource.post(hydrate=True, return_timeout=10)
        print(resource)

Try it out

    CifsService(
        {
            "ad_domain": {"fqdn": "ONTAPAVC.COM", "organizational_unit": "CN=Computers"},
            "name": "CIFS1",
            "security": {
                "encrypt_dc_connection": False,
                "smb_encryption": False,
                "smb_signing": False,
                "session_security": "none",
                "aes_netlogon_enabled": False,
                "try_ldap_channel_binding": False,
                "use_start_tls": False,
                "lm_compatibility_level": "lm_ntlm_ntlmv2_krb",
                "restrict_anonymous": "no_enumeration",
                "kdc_encryption": False,
                "use_ldaps": False,
            },
            "options": {
                "null_user_windows_name": "string",
                "path_component_cache": True,
                "fsctl_trim": True,
                "junction_reparse": True,
                "advanced_sparse_file": True,
                "multichannel": True,
                "smb_credits": 128,
                "widelink_reparse_versions": ["smb1"],
                "referral": False,
                "fake_open": True,
                "large_mtu": True,
                "admin_to_root_mapping": True,
                "copy_offload": True,
            },
            "default_unix_user": "string",
            "netbios": {
                "wins_servers": ["10.224.65.20", "10.224.65.21"],
                "aliases": ["ALIAS_1", "ALIAS_2", "ALIAS_3"],
                "enabled": False,
            },
            "enabled": True,
            "comment": "This CIFS Server Belongs to CS Department",
            "svm": {"name": "vs1", "uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"},
        }
    )

### Creating a CIFS server when using AKV

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsService()
        resource.key_vault_uri = "https://testkv.vault.azure.net"
        resource.client_secret = "<CLIENT-SECRET-ACCESS-KEY>"
        resource.authentication_method = "client_secret"
        resource.tenant_id = "c9f32fcb-4ab7-40fe-af1b-1850d46cfbbe"
        resource.client_id = "e959d1b5-5a63-4284-9268-851e30e3eceb"
        resource.ad_domain = {
            "fqdn": "ontapavc.com",
            "organizational_unit": "CN=Computers",
            "user": "administrator",
        }
        resource.comment = "This CIFS Server Belongs to CS Department"
        resource.default_unix_user = "string"
        resource.enabled = True
        resource.name = "CIFS1"
        resource.netbios = {
            "aliases": ["ALIAS_1", "ALIAS_2", "ALIAS_3"],
            "enabled": False,
            "wins_servers": ["10.224.65.20", "10.224.65.21"],
        }
        resource.options = {
            "admin_to_root_mapping": True,
            "advanced_sparse_file": True,
            "copy_offload": True,
            "fake_open": True,
            "fsctl_trim": True,
            "junction_reparse": True,
            "large_mtu": True,
            "multichannel": True,
            "null_user_windows_name": "string",
            "path_component_cache": True,
            "referral": False,
            "smb_credits": 128,
            "widelink_reparse_versions": ["smb1"],
        }
        resource.security = {
            "encrypt_dc_connection": False,
            "kdc_encryption": False,
            "restrict_anonymous": "no_enumeration",
            "session_security": "none",
            "smb_encryption": False,
            "smb_signing": False,
            "use_ldaps": False,
            "use_start_tls": False,
        }
        resource.svm = {"name": "vs1", "uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"}
        resource.post(hydrate=True, return_timeout=10)
        print(resource)

Try it out

    CifsService(
        {
            "ad_domain": {"fqdn": "ONTAPAVC.COM", "organizational_unit": "CN=Computers"},
            "name": "CIFS1",
            "security": {
                "encrypt_dc_connection": False,
                "smb_encryption": False,
                "smb_signing": False,
                "session_security": "none",
                "aes_netlogon_enabled": False,
                "try_ldap_channel_binding": False,
                "use_start_tls": False,
                "lm_compatibility_level": "lm_ntlm_ntlmv2_krb",
                "restrict_anonymous": "no_enumeration",
                "kdc_encryption": False,
                "use_ldaps": False,
            },
            "options": {
                "null_user_windows_name": "string",
                "path_component_cache": True,
                "fsctl_trim": True,
                "junction_reparse": True,
                "advanced_sparse_file": True,
                "multichannel": True,
                "smb_credits": 128,
                "widelink_reparse_versions": ["smb1"],
                "referral": False,
                "fake_open": True,
                "large_mtu": True,
                "admin_to_root_mapping": True,
                "copy_offload": True,
            },
            "default_unix_user": "string",
            "netbios": {
                "wins_servers": ["10.224.65.20", "10.224.65.21"],
                "aliases": ["ALIAS_1", "ALIAS_2", "ALIAS_3"],
                "enabled": False,
            },
            "enabled": True,
            "comment": "This CIFS Server Belongs to CS Department",
            "svm": {"name": "vs1", "uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"},
        }
    )

### Creating a CIFS server for Hybrid user

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsService()
        resource.auth_user_type = "hybrid_user"
        resource.client_certificate = "certificate added to azure application"
        resource.authentication_method = "certificate"
        resource.tenant_id = "c9f32fcb-4ab7-40fe-af1b-1850d46cfbbe"
        resource.client_id = "e959d1b5-5a63-4284-9268-851e30e3eceb"
        resource.ad_domain = {"fqdn": "ontapavc.com", "organizational_unit": "CN=Computers"}
        resource.comment = "This CIFS Server Belongs to CS Department"
        resource.enabled = True
        resource.name = "CIFS1"
        resource.svm = {"name": "vs1", "uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"}
        resource.post(hydrate=True, return_timeout=10)
        print(resource)

Try it out

    CifsService(
        {
            "ad_domain": {"fqdn": "ONTAPAVC.COM", "organizational_unit": "CN=Computers"},
            "name": "CIFS1",
            "enabled": True,
            "comment": "This CIFS Server Belongs to CS Department",
            "svm": {"name": "vs1", "uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"},
        }
    )

### Creating a CIFS server when using the security.advertised_kdc_encryptions field

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsService()
        resource.ad_domain = {
            "fqdn": "testdomain.com",
            "organizational_unit": "CN=Computers",
            "password": "<PASSWORD-FOR-USER>",
            "user": "administrator",
        }
        resource.enabled = True
        resource.name = "CIFS_server1"
        resource.security = {"advertised_kdc_encryptions": ["aes-128"]}
        resource.svm = {"name": "testvs", "uuid": "508375d4-fb16-11ee-a792-005056a75b5c"}
        resource.post(hydrate=True, return_timeout=120, force=True)
        print(resource)

Try it out

    CifsService(
        {
            "ad_domain": {
                "default_site": "",
                "fqdn": "TESTDOMAIN.COM",
                "organizational_unit": "CN=Computers",
            },
            "name": "CIFS_SERVER1",
            "security": {
                "encrypt_dc_connection": False,
                "smb_encryption": False,
                "smb_signing": False,
                "session_security": "none",
                "ldap_referral_enabled": False,
                "advertised_kdc_encryptions": ["aes_128"],
                "aes_netlogon_enabled": False,
                "try_ldap_channel_binding": True,
                "use_start_tls": False,
                "lm_compatibility_level": "lm_ntlm_ntlmv2_krb",
                "restrict_anonymous": "no_enumeration",
                "kdc_encryption": True,
                "use_ldaps": False,
            },
            "options": {
                "path_component_cache": True,
                "fsctl_trim": True,
                "junction_reparse": True,
                "export_policy_enabled": False,
                "advanced_sparse_file": True,
                "multichannel": False,
                "smb_credits": 512,
                "widelink_reparse_versions": ["smb1"],
                "shadowcopy_dir_depth": 5,
                "referral": False,
                "fake_open": True,
                "large_mtu": True,
                "admin_to_root_mapping": True,
                "shadowcopy": True,
                "copy_offload": True,
            },
            "default_unix_user": "pcuser",
            "netbios": {"wins_servers": [], "enabled": False},
            "enabled": True,
            "statistics": {
                "throughput_raw": {"write": 0, "total": 0, "read": 0},
                "iops_raw": {"write": 0, "total": 0, "other": 0, "read": 0},
                "timestamp": "2024-04-16T15:17:41+00:00",
                "status": "ok",
                "latency_raw": {"write": 0, "total": 0, "other": 0, "read": 0},
            },
            "comment": "",
            "group_policy_object_enabled": False,
            "svm": {"name": "testvs", "uuid": "508375d4-fb16-11ee-a792-005056a75b5c"},
        }
    )

### Retrieving the full CIFS server configuration for all SVMs in the cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(CifsService.get_collection(fields="*", return_timeout=15)))

Try it out

    [
        CifsService(
            {
                "ad_domain": {
                    "fqdn": "ONTAPAVC.COM",
                    "organizational_unit": "CN=Computers",
                },
                "name": "CIFS1",
                "security": {
                    "encrypt_dc_connection": False,
                    "smb_encryption": False,
                    "smb_signing": False,
                    "session_security": "none",
                    "aes_netlogon_enabled": False,
                    "try_ldap_channel_binding": False,
                    "use_start_tls": False,
                    "lm_compatibility_level": "lm_ntlm_ntlmv2_krb",
                    "restrict_anonymous": "no_enumeration",
                    "kdc_encryption": False,
                    "use_ldaps": False,
                },
                "options": {
                    "null_user_windows_name": "string",
                    "path_component_cache": True,
                    "fsctl_trim": True,
                    "junction_reparse": True,
                    "advanced_sparse_file": True,
                    "multichannel": True,
                    "smb_credits": 128,
                    "widelink_reparse_versions": ["smb1"],
                    "referral": False,
                    "fake_open": True,
                    "large_mtu": True,
                    "admin_to_root_mapping": True,
                    "copy_offload": True,
                },
                "default_unix_user": "string",
                "netbios": {
                    "wins_servers": ["10.224.65.20", "10.224.65.21"],
                    "aliases": ["ALIAS_1", "ALIAS_2", "ALIAS_3"],
                    "enabled": False,
                },
                "enabled": True,
                "comment": "This CIFS Server Belongs to CS Department",
                "svm": {"name": "vs1", "uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"},
            }
        )
    ]

### Retrieving CIFS server configuration details for a specific SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsService(**{"svm.uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"})
        resource.get()
        print(resource)

Try it out

    CifsService(
        {
            "ad_domain": {"fqdn": "ONTAPAVC.COM", "organizational_unit": "CN=Computers"},
            "name": "CIFS1",
            "security": {
                "encrypt_dc_connection": False,
                "smb_encryption": False,
                "smb_signing": False,
                "session_security": "none",
                "aes_netlogon_enabled": False,
                "try_ldap_channel_binding": False,
                "use_start_tls": False,
                "lm_compatibility_level": "lm_ntlm_ntlmv2_krb",
                "restrict_anonymous": "no_enumeration",
                "kdc_encryption": False,
                "use_ldaps": False,
            },
            "options": {
                "null_user_windows_name": "string",
                "path_component_cache": True,
                "fsctl_trim": True,
                "junction_reparse": True,
                "advanced_sparse_file": True,
                "multichannel": True,
                "smb_credits": 128,
                "widelink_reparse_versions": ["smb1"],
                "referral": False,
                "fake_open": True,
                "large_mtu": True,
                "admin_to_root_mapping": True,
                "copy_offload": True,
            },
            "default_unix_user": "string",
            "netbios": {
                "wins_servers": ["10.224.65.20", "10.224.65.21"],
                "aliases": ["ALIAS_1", "ALIAS_2", "ALIAS_3"],
                "enabled": False,
            },
            "enabled": True,
            "comment": "This CIFS Server Belongs to CS Department",
            "svm": {"name": "vs1", "uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"},
        }
    )

### Updating CIFS server properties for the specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsService(**{"svm.uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"})
        resource.comment = "CIFS SERVER MODIFICATION"
        resource.patch()

### Removing a CIFS server for a specific SVM

To delete a CIFS server, use the following API. This will delete the CIFS server along with other CIFS configurations such as CIFS share, share ACLs, homedir search-path, and so on.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsService(**{"svm.uuid": "e0c20d9c-96cd-11eb-97da-0050568e684d"})
        resource.delete(
            body={
                "ad_domain": {
                    "fqdn": "ontapavc.com",
                    "organizational_unit": "CN=Computers",
                    "password": "<PASSWORD-FOR-USER>",
                    "user": "administrator",
                },
                "force": True,
            }
        )

## Classes

`class CifsService (*args, **kwargs)`

  Allows interaction with CifsService objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all CifsService resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('CifsService')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a CIFS server and related CIFS configurations.
    Important notes: * The default value for the "force" field is false. * If the "force" field is set along with user login credentials, the local CIFS configuration will be deleted irrespective of any communication errors. * If the "force" field alone is set without passing the user login credentials, the local CIFS configuration will be deleted by not making any request to Active Directory.

    ### Related ONTAP commands

    - `vserver cifs server delete`
    - `vserver cifs remove-netbios-aliases`

    ### Learn more

    - `DOC /protocols/cifs/services`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent CifsService resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves CIFS servers.

    ### Expensive properties

    There is an added computational cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver cifs server show`
    - `vserver cifs server options show`
    - `vserver cifs server security show`

    ### Learn more

    - `DOC /protocols/cifs/services`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves CIFS servers.

    ### Expensive properties

    There is an added computational cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver cifs server show`
    - `vserver cifs server options show`
    - `vserver cifs server security show`

    ### Learn more

    - `DOC /protocols/cifs/services`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('CifsService')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates both the mandatory and optional parameters of the CIFS configuration. Ensure the CIFS server is administratively disabled when renaming the CIFS server or modifying the ad_domain properties.

    ### Related ONTAP commands

    - `vserver cifs server modify`
    - `vserver cifs server options modify`
    - `vserver cifs security modify`
    - `vserver cifs server add-netbios-aliases`
    - `vserver cifs server remove-netbios-aliases`
    - `vserver cifs group-policy modify`

    ### Learn more

    - `DOC /protocols/cifs/services`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('CifsService')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[CifsService], NetAppResponse]`

    Creates a CIFS server. Each SVM can have one CIFS server.

    ### Important notes

    - The CIFS server name might or might not be the same as the SVM name.
    - The CIFS server name can contain up to 15 characters.
    - The CIFS server name does not support the following characters: @ # * ( ) = + [ ] | ; : " , < > / ?

    ### Required properties when creating CIFS server with Windows Active Directory domain

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the CIFS server.
    - `name` - Name of the CIFS server.
    - `ad_domain.fqdn` - Fully qualified domain name of the Windows Active Directory to which this CIFS server belongs.
    - `ad_domain.user` - User account with the access to add the CIFS server to the Active Directory.
    - `ad_domain.password` - Account password used to add this CIFS server to the Active Directory.

    ### Required properties when creating CIFS server in Workgroup mode

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the CIFS server.
    - `name` - Name of the CIFS server.
    - `workgroup` - Name of the workgroup to which this CIFS server belongs.

    ### Required properties when using AKV for authentication (ANF platform)

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the CIFS server.
    - `name` - Name of the CIFS server.
    - `ad_domain.user` - User account with the access to add the CIFS server to the Active Directory.
    - `ad_domain.fqdn` - Fully qualified domain name of the Windows Active Directory to which this CIFS server belongs.
    - `client_id` - Application client ID of the deployed Azure application with appropriate access to an AKV or EntraId.
    - `tenant_id` - Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV or EntraId.
    - `key_vault_uri` - URI of the deployed AKV that is used by ONTAP for storing keys.
    - `authentication_method` - Authentication method used by the application to prove its identity to AKV or EntraId. It can be either "client_secret" or "certificate".
    - `auth_user_type` - Type of user who can access the SMB Volume. It can be either "domain_user" or "hybrid_user". The default is domain_user. In the case of a hybrid-user, ONTAP cannot access on-premise ADDS.
    - `client_secret` - Secret used by the application to prove its identity to AKV.
    - `client_certificate` - Base64 encoded PKCS12 certificate used by the application to prove its identity to AKV.

    ### Recommended optional properties

    - `comment` - Add a text comment of up to 256 characters about the CIFS server.
    - `netbios.aliases` - Add a comma-delimited list of one or more NetBIOS aliases for the CIFS server.
    - `netbios.wins_servers` - Add a list of Windows Internet Name Server (WINS) addresses that manage and map the NetBIOS name of the CIFS server to their network IP addresses. The IP addresses must be IPv4 addresses.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `ad_domain.organizational_unit` - CN=Computers * `enabled` - true * `security.restrict_anonymous` - no_enumeration * `security.smb_signing` - false * `security.smb_encryption` - false * `security.encrypt_dc_connection` - false * `default_unix_user` - pcuser * `netbios.enabled` - false However, if either "netbios.wins-server" or "netbios.aliases" is set during POST and if `netbios.enabled` is not specified then `netbios.enabled` is set to true. * `security.aes_netlogon_enabled` - false * `security.try_ldap_channel_binding` - true * `security.ldap_referral_enabled` - false

    ### Related ONTAP commands

    - `vserver cifs server create`
    - `vserver cifs server options modify`
    - `vserver cifs security modify`
    - `vserver cifs server add-netbios-aliases`

    ### Learn more

    - `DOC /protocols/cifs/services`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes a CIFS server and related CIFS configurations.
    Important notes: * The default value for the "force" field is false. * If the "force" field is set along with user login credentials, the local CIFS configuration will be deleted irrespective of any communication errors. * If the "force" field alone is set without passing the user login credentials, the local CIFS configuration will be deleted by not making any request to Active Directory.

    ### Related ONTAP commands

    - `vserver cifs server delete`
    - `vserver cifs remove-netbios-aliases`

    ### Learn more

    - `DOC /protocols/cifs/services`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves a CIFS server.

    ### Related ONTAP commands

    - `vserver cifs server show`
    - `vserver cifs server options show`
    - `vserver cifs server security show`

    ### Learn more

    - `DOC /protocols/cifs/services`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates both the mandatory and optional parameters of the CIFS configuration. Ensure the CIFS server is administratively disabled when renaming the CIFS server or modifying the ad_domain properties.

    ### Related ONTAP commands

    - `vserver cifs server modify`
    - `vserver cifs server options modify`
    - `vserver cifs security modify`
    - `vserver cifs server add-netbios-aliases`
    - `vserver cifs server remove-netbios-aliases`
    - `vserver cifs group-policy modify`

    ### Learn more

    - `DOC /protocols/cifs/services`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates a CIFS server. Each SVM can have one CIFS server.

    ### Important notes

    - The CIFS server name might or might not be the same as the SVM name.
    - The CIFS server name can contain up to 15 characters.
    - The CIFS server name does not support the following characters: @ # * ( ) = + [ ] | ; : " , < > / ?

    ### Required properties when creating CIFS server with Windows Active Directory domain

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the CIFS server.
    - `name` - Name of the CIFS server.
    - `ad_domain.fqdn` - Fully qualified domain name of the Windows Active Directory to which this CIFS server belongs.
    - `ad_domain.user` - User account with the access to add the CIFS server to the Active Directory.
    - `ad_domain.password` - Account password used to add this CIFS server to the Active Directory.

    ### Required properties when creating CIFS server in Workgroup mode

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the CIFS server.
    - `name` - Name of the CIFS server.
    - `workgroup` - Name of the workgroup to which this CIFS server belongs.

    ### Required properties when using AKV for authentication (ANF platform)

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the CIFS server.
    - `name` - Name of the CIFS server.
    - `ad_domain.user` - User account with the access to add the CIFS server to the Active Directory.
    - `ad_domain.fqdn` - Fully qualified domain name of the Windows Active Directory to which this CIFS server belongs.
    - `client_id` - Application client ID of the deployed Azure application with appropriate access to an AKV or EntraId.
    - `tenant_id` - Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV or EntraId.
    - `key_vault_uri` - URI of the deployed AKV that is used by ONTAP for storing keys.
    - `authentication_method` - Authentication method used by the application to prove its identity to AKV or EntraId. It can be either "client_secret" or "certificate".
    - `auth_user_type` - Type of user who can access the SMB Volume. It can be either "domain_user" or "hybrid_user". The default is domain_user. In the case of a hybrid-user, ONTAP cannot access on-premise ADDS.
    - `client_secret` - Secret used by the application to prove its identity to AKV.
    - `client_certificate` - Base64 encoded PKCS12 certificate used by the application to prove its identity to AKV.

    ### Recommended optional properties

    - `comment` - Add a text comment of up to 256 characters about the CIFS server.
    - `netbios.aliases` - Add a comma-delimited list of one or more NetBIOS aliases for the CIFS server.
    - `netbios.wins_servers` - Add a list of Windows Internet Name Server (WINS) addresses that manage and map the NetBIOS name of the CIFS server to their network IP addresses. The IP addresses must be IPv4 addresses.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `ad_domain.organizational_unit` - CN=Computers * `enabled` - true * `security.restrict_anonymous` - no_enumeration * `security.smb_signing` - false * `security.smb_encryption` - false * `security.encrypt_dc_connection` - false * `default_unix_user` - pcuser * `netbios.enabled` - false However, if either "netbios.wins-server" or "netbios.aliases" is set during POST and if `netbios.enabled` is not specified then `netbios.enabled` is set to true. * `security.aes_netlogon_enabled` - false * `security.try_ldap_channel_binding` - true * `security.ldap_referral_enabled` - false

    ### Related ONTAP commands

    - `vserver cifs server create`
    - `vserver cifs server options modify`
    - `vserver cifs security modify`
    - `vserver cifs server add-netbios-aliases`

    ### Learn more

    - `DOC /protocols/cifs/services`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class CifsServiceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CifsService object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ad_domain: AdDomain GET POST PATCH`

    The ad_domain field of the cifs_service.

  `auth_style: str GET`

    Authentication type.

    Valid choices:

    - domain
    - workgroup
  `auth_user_type: str GET POST PATCH`

    Specifies the type of user who can access the SMB Volume. The default is domain_user. In the case of a hybrid-user, ONTAP won't contact on-premise ADDS.

    Valid choices:

    - domain_user
    - hybrid_user
  `authentication_method: str GET POST PATCH`

    Specifies the authentication method. The available values are:

    - client_secret
    - certificate

    Valid choices:

    - client_secret
    - certificate
  `client_certificate: str POST PATCH`

    PKCS12 certificate used by the application to prove its identity to AKV.

    Example: PEM Cert

  `client_id: str GET POST PATCH`

    Application client ID of the deployed Azure application with appropriate access to an AKV or EntraId.

    Example: e959d1b5-5a63-4284-9268-851e30e3eceb

  `client_secret: str POST PATCH`

    Secret used by the application to prove its identity to AKV.

    Example:

  `comment: str GET POST PATCH`

    A descriptive text comment for the CIFS server. SMB clients can see the CIFS server comment when browsing servers on the network. If there is a space in the comment, you must enclose the entire string in quotation marks.

    Example: This CIFS Server Belongs to CS Department

  `default_unix_user: str GET POST PATCH`

    Specifies the UNIX user to which any authenticated CIFS user is mapped to, if the normal user mapping rules fails.

  `enabled: bool GET POST PATCH`

    Specifies if the CIFS service is administratively enabled.

  `group_policy_object_enabled: bool GET PATCH`

    If set to true, group policies will be applied to the SVM.

  `key_vault_uri: str GET POST PATCH`

    URI of the deployed AKV that is used by ONTAP for storing keys.

    Example: https://kmip-akv-keyvault.vault.azure.net/

  `links: SelfLink GET`

    The links field of the cifs_service.

  `metric: PerformanceMetricSvm GET`

    The metric field of the cifs_service.

  `name: str GET POST PATCH`

    The name of the CIFS server.

    Example: CIFS1

  `netbios: CifsNetbios GET POST PATCH`

    The netbios field of the cifs_service.

  `oauth_host: str GET POST PATCH`

    Open authorization server host name.

    Example: login.microsoftonline.com

  `options: CifsServiceOptions GET POST PATCH`

    The options field of the cifs_service.

  `proxy_host: str GET POST PATCH`

    Proxy host.

    Example: proxy.eng.com

  `proxy_password: str POST PATCH`

    Proxy password. Password is not audited.

    Example: proxypassword

  `proxy_port: Size GET POST PATCH`

    Proxy port.

    Example: 1234

  `proxy_type: str GET POST PATCH`

    Proxy type.

    Valid choices:

    - http
    - https
  `proxy_username: str GET POST PATCH`

    Proxy username.

    Example: proxyuser

  `security: CifsServiceSecurity GET POST PATCH`

    The security field of the cifs_service.

  `statistics: PerformanceMetricRawSvm GET`

    The statistics field of the cifs_service.

  `svm: Svm GET POST`

    The svm field of the cifs_service.

  `tenant_id: str GET POST PATCH`

    Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV or EntraId.

    Example: c9f32fcb-4ab7-40fe-af1b-1850d46cfbbe

  `timeout: Size GET POST PATCH`

    AKV connection timeout, in seconds. The allowed range is between 0 to 30 seconds.

    Example: 25

  `verify_host: bool GET POST PATCH`

    Verify the identity of the AKV host name. By default, verify_host is set to true.

  `workgroup: str GET POST PATCH`

    The workgroup name.

    Example: workgrp1